@@ -9,11 +9,11 @@
 
 """Several utilities for objects in general."""
 
+import sys
 from contextlib import contextmanager
 
-from xotl.tools.symbols import Unset
 from xotl.tools.deprecation import deprecated
-
+from xotl.tools.symbols import Unset
 
 __docstring_format__ = "rst"
 
@@ -116,10 +116,7 @@ class SafeDataItem:
             if not isinstance(current, SafeDataItem):
                 cls_locals[self.attr_name] = self
             else:
-                msg = (
-                    "class `%s` has already an assigned descriptor with "
-                    "the same name `%s`"
-                )
+                msg = "class `%s` has already an assigned descriptor with the same name `%s`"
                 type_name = type(self).__name__
                 raise AttributeError(msg % (type_name, self.attr_name))
 
@@ -186,6 +183,7 @@ class SafeDataItem:
 
         def inner(method):
             from types import FunctionType as function
+
             from xotl.tools.validators import check
 
             FUNC_KINDS = ("normal", "static", "class")
@@ -269,6 +267,7 @@ class SafeDataItem:
     def _unique_name(self):
         """Generate a unique new name."""
         from time import time
+
         from xotl.tools.bases import int2str
 
         return "_%s" % int2str(int(1000000 * time()))
@@ -311,10 +310,7 @@ class SafeDataItem:
                 bads[key] = value
         self.validator = predicate(self.validator)
         if bads:
-            msg = (
-                "Invalid keyword arguments: %s\n"
-                "See constructor documentation for more info."
-            )
+            msg = "Invalid keyword arguments: %s\n" "See constructor documentation for more info."
             raise ValueError(msg % bads)
         if self.attr_name is Unset:
             from xotl.tools.names import nameof
@@ -393,8 +389,8 @@ def smart_setter(obj):
     .. versionadded:: 1.8.2
 
     """
-    from xotl.tools.future.functools import partial
     from xotl.tools.future.collections import MutableMapping
+    from xotl.tools.future.functools import partial
 
     if isinstance(obj, MutableMapping):
         return obj.__setitem__
@@ -556,7 +552,13 @@ def build_documentation(cls, get_doc=None, deep=1):
     return res
 
 
-def fix_class_documentation(cls, ignore=None, min_length=10, deep=1, default=None):
+def fix_class_documentation(
+    cls,
+    ignore=None,
+    min_length=10,
+    deep=1,
+    default=None,
+):
     """Fix the documentation for the given class using its super-classes.
 
     This function may be useful for shells or Python Command Line Interfaces
@@ -589,9 +591,7 @@ def fix_class_documentation(cls, ignore=None, min_length=10, deep=1, default=Non
             cls.__doc__ = default(cls) if callable(default) else default
 
 
-def fix_method_documentation(
-    cls, method_name, ignore=None, min_length=10, deep=1, default=None
-):
+def fix_method_documentation(cls, method_name, ignore=None, min_length=10, deep=1, default=None):
     """Fix the documentation for the given class using its super-classes.
 
     This function may be useful for shells or Python Command Line Interfaces
@@ -631,7 +631,7 @@ def fix_method_documentation(
 
 def fulldir(obj):
     """Return a set with all attribute names defined in `obj`"""
-    from xotl.tools.future.inspect import get_attr_value, _static_getmro
+    from xotl.tools.future.inspect import _static_getmro, get_attr_value
 
     def getdir(o):
         return set(get_attr_value(o, "__dict__", {}))
@@ -922,37 +922,6 @@ def get_branch_subclasses(cls, *, include_this=False):
     return list(iter_branch_subclasses(cls, include_this=include_this))
 
 
-@deprecated(iter_branch_subclasses)
-def iter_final_subclasses(cls, *, include_this=True):
-    """Iterate over the final sub-classes of `cls`.
-
-    Final classes are those which has no sub-classes.  If `cls` is final, the
-    iterator yields only `cls` unless `include_this` is False.
-
-    .. versionadded:: 2.1.0
-
-    .. deprecated:: 2.1.5 This is actually a duplicate of
-                    `iter_branch_subclasses`:func:.
-
-    """
-    return iter_branch_subclasses(cls, include_this=include_this)
-
-
-@deprecated(get_branch_subclasses)
-def get_final_subclasses(cls, *, include_this=True):
-    """List final sub-classes of `cls`.
-
-    See `iter_final_subclasses`:func:.
-
-    .. versionadded:: 2.1.0
-
-    .. deprecated:: 2.1.5 This is a duplicate of
-                   `get_branch_subclasses`:func:.
-
-    """
-    return list(iter_final_subclasses(cls, include_this=include_this))
-
-
 def FinalSubclassEnumeration(superclass, *, dynamic=True):
     """A final sub-class enumeration.
 
@@ -975,8 +944,7 @@ def FinalSubclassEnumeration(superclass, *, dynamic=True):
         def __members__(self):
             if self._cached_members is None or self._dynamic:
                 result = {
-                    c.__name__: c
-                    for c in iter_branch_subclasses(superclass, include_this=False)
+                    c.__name__: c for c in iter_branch_subclasses(superclass, include_this=False)
                 }
                 if not self._dynamic:
                     self._cached_members = dict(result)
@@ -1046,8 +1014,29 @@ class xproperty(property):
         return self.fget(instance if instance is not None else owner)
 
 
-class classproperty(property):
-    """A descriptor that behaves like property for instances but for classes.
+if sys.version_info >= (3, 9):
+
+    def classproperty(*args, **kwargs):
+        return classmethod(property(*args, **kwargs))
+
+
+else:
+
+    class classproperty(property):
+        def __get__(self, instance, owner):
+            obj = type(instance) if instance is not None else owner
+            return super().__get__(obj, owner)
+
+        def __set__(self, instance, value):
+            obj = instance if isinstance(instance, type) else type(instance)
+            super().__set__(obj, value)
+
+        def __delete__(self, instance):
+            obj = instance if isinstance(instance, type) else type(instance)
+            super().__delete__(obj)
+
+
+classproperty.__doc__ = """A descriptor that behaves like property for instances but for classes.
 
     Example of its use::
 
@@ -1070,24 +1059,19 @@ class classproperty(property):
                 cls.x = int(x)
             name = classproperty(_get_name, _set_name)
 
+    In Python 3.9+ this is actually the composition of `classmethod`:any: to
+    `property`:any: (i.e same as ``lambda *a, **kw: classmethod(property(*a,
+    **kw))``).
+
     .. versionadded:: 1.4.1
 
     .. versionchanged:: 1.8.0 Inherits from `property`
 
+    .. versionchanged:: 2.11.0 Changed to be ``compose(classmethod,
+       property)`` in Python 3.9+.
+
     """
 
-    def __get__(self, instance, owner):
-        obj = type(instance) if instance is not None else owner
-        return super().__get__(obj, owner)
-
-    def __set__(self, instance, value):
-        obj = instance if isinstance(instance, type) else type(instance)
-        super().__set__(obj, value)
-
-    def __delete__(self, instance):
-        obj = instance if isinstance(instance, type) else type(instance)
-        super().__delete__(obj)
-
 
 class staticproperty(property):
     """A descriptor that behaves like properties for instances but static.
@@ -1136,41 +1120,44 @@ class staticproperty(property):
             raise AttributeError("can't delete attribute")
 
 
-# The following is extracted from the SQLAlchemy project's codebase, merit and
-# copyright goes to SQLAlchemy authors.
-#
-# Copyright (C) 2005-2011 the SQLAlchemy authors and contributors
-#
-# This module is part of SQLAlchemy and is released under the MIT License:
-# http://www.opensource.org/licenses/mit-license.php
-#
-class memoized_property:
-    """A read-only property that is only evaluated once.
+try:
+    from functools import cached_property
 
-    This is extracted from the SQLAlchemy project's codebase, merit and
-    copyright goes to SQLAlchemy authors::
+    class memoized_property(cached_property):
+        def __init__(self, func, doc=None):
+            super().__init__(func)
+            self.__doc__ = doc or func.__doc__
+            self.__name__ = func.__name__
 
-      Copyright (C) 2005-2011 the SQLAlchemy authors and contributors
+        def reset(self, instance):
+            """Clear the cached value of `instance`."""
+            instance.__dict__.pop(self.__name__, None)
 
-      This module is part of SQLAlchemy and is released under the MIT License:
-      http://www.opensource.org/licenses/mit-license.php
 
-    """
+except ImportError:
+    # The following is extracted from the SQLAlchemy project's codebase, merit and
+    # copyright goes to SQLAlchemy authors.
+    #
+    # Copyright (C) 2005-2011 the SQLAlchemy authors and contributors
+    #
+    # This module is part of SQLAlchemy and is released under the MIT License:
+    # http://www.opensource.org/licenses/mit-license.php
+    #
+    class memoized_property:
+        def __init__(self, fget, doc=None):
+            self.fget = fget
+            self.__doc__ = doc or fget.__doc__
+            self.__name__ = fget.__name__
 
-    def __init__(self, fget, doc=None):
-        self.fget = fget
-        self.__doc__ = doc or fget.__doc__
-        self.__name__ = fget.__name__
+        def __get__(self, obj, cls):
+            if obj is None:
+                return self
+            obj.__dict__[self.__name__] = result = self.fget(obj)
+            return result
 
-    def __get__(self, obj, cls):
-        if obj is None:
-            return self
-        obj.__dict__[self.__name__] = result = self.fget(obj)
-        return result
-
-    def reset(self, instance):
-        """Clear the cached value of `instance`."""
-        instance.__dict__.pop(self.__name__, None)
+        def reset(self, instance):
+            """Clear the cached value of `instance`."""
+            instance.__dict__.pop(self.__name__, None)
 
 
 def setdefaultattr(obj, name, value):
@@ -1188,8 +1175,8 @@ def setdefaultattr(obj, name, value):
         >>> setdefaultattr(inst, 'spam', 'with ham')
         'egg'
 
-    (`New in version 1.2.1`). If you want the value to be lazily evaluated you
-    may provide a lazy-lambda::
+    .. versionadded: 1.2.1 If you want the value to be lazily evaluated you
+       may provide a lazy-lambda::
 
         >>> inst = Someclass()
         >>> inst.a = 1
@@ -1236,7 +1223,13 @@ def adapt_exception(value, **kwargs):
         return None
 
 
-def copy_class(cls, meta=None, ignores=None, new_attrs=None, new_name=None):
+def copy_class(
+    cls,
+    meta=None,
+    ignores=None,
+    new_attrs=None,
+    new_name=None,
+):
     """Copies a class definition to a new class.
 
     The returned class will have the same name, bases and module of `cls`.
@@ -1268,6 +1261,7 @@ def copy_class(cls, meta=None, ignores=None, new_attrs=None, new_name=None):
 
     """
     from types import new_class
+
     from xotl.tools.future.types import MemberDescriptorType
 
     def _get_ignored(what):
@@ -1364,7 +1358,7 @@ def smart_copy(*args, defaults=None):
     .. versionchanged:: 1.7.0 `defaults` is now keyword only.
 
     """
-    from xotl.tools.future.collections import MutableMapping, Mapping
+    from xotl.tools.future.collections import Mapping, MutableMapping
     from xotl.tools.symbols import Undefined
     from xotl.tools.validators.identifiers import is_valid_identifier
     from xotl.tools.values.simple import logic_iterable_coerce, nil
@@ -1389,9 +1383,7 @@ def smart_copy(*args, defaults=None):
 
     _mapping = isinstance(defaults, Mapping)
     if _mapping or logic_iterable_coerce(defaults) is not nil:
-        for key, val in (
-            (key, get_first_of(sources, key, default=Unset)) for key in defaults
-        ):
+        for key, val in ((key, get_first_of(sources, key, default=Unset)) for key in defaults):
             if val is Unset:
                 if _mapping:
                     val = defaults.get(key, None)
@@ -1486,7 +1478,6 @@ def get_traverser(*paths, default=Unset, sep=".", getter=None):
     .. versionadded:: 1.5.3
 
     """
-    from xotl.tools.params import check_count
 
     def _traverser(path, default=default, sep=sep, getter=getter):
         if not getter:
@@ -1544,7 +1535,7 @@ def dict_merge(*dicts, **others):
     Without arguments, return the empty dict.
 
     """
-    from collections.abc import Mapping, Sequence, Set, Container
+    from collections.abc import Container, Mapping, Sequence, Set
 
     if others:
         dicts = dicts + (others,)
@@ -1738,9 +1729,7 @@ def delegator(attribute, attrs_map, metaclass=type):
     .. versionadded:: 1.9.3
 
     """
-    descriptors = {
-        key: DelegatedAttribute(attribute, attr) for key, attr in attrs_map.items()
-    }
+    descriptors = {key: DelegatedAttribute(attribute, attr) for key, attr in attrs_map.items()}
     return metaclass("delegator", (object,), descriptors)
 
 
@@ -1783,4 +1772,4 @@ class DelegatedAttribute:
         return "<DelegatedAttr '%s.%s'>" % (self.target_name, self.attr)
 
 
-del contextmanager, deprecated
+del contextmanager, deprecated, sys
